@@ -1,13 +1,29 @@
 lhc_generate_lhc_sample <-
-function(FILEPATH,PARAMETERS,NUMSAMPLES,PMIN,PMAX)
+function(FILEPATH,PARAMETERS,NUMSAMPLES,PMIN,PMAX,ALGORITHM)
 {
 	if(file.exists(FILEPATH))
 	{
 		NUMPARAMS<-length(PARAMETERS)
 
-		# PERFORM THE SAMPLING
-		# MAY TAKE A WHILE FOR A LARGE NUMBER OF SAMPLES (THIS BEING TWO DAYS WHERE NUMSAMPLES=500)
-		design<-optimumLHS(NUMSAMPLES,NUMPARAMS,maxSweeps=2,eps=.1)
+		ALGORITHM<-tolower(ALGORITHM)
+
+		# PERFORM THE SAMPLING - JUDGING ON USERS CHOICE OF ALGORITHM
+		if(ALGORITHM=="optimum")
+		{
+			# MAY TAKE A WHILE FOR A LARGE NUMBER OF SAMPLES (THIS BEING TWO DAYS WHERE NUMSAMPLES=500)
+			design<-optimumLHS(NUMSAMPLES,NUMPARAMS,maxSweeps=2,eps=.1)
+		}
+		else
+		{
+			design<-randomLHS(NUMSAMPLES,NUMPARAMS)
+		}
+
+
+
+
+
+
+
 
 		# NOW LOOK AT THE VALUE CHOSEN FOR EACH SAMPLE, AS THESE WILL CURRENTLY BE BETWEEN 0 AND 1 
 		for(k in 1:NUMSAMPLES)
