@@ -5,8 +5,8 @@ function(FILEPATH,PARAMETERS,MEASURES,MEASURE_SCALE,LHCSUMMARYFILENAME,CORCOEFFS
 	for(n in 1:length(TIMEPOINTS))
 	{
 		TIMEPOINTANALYSED<-TIMEPOINTS[n]
-		CORCOEFFSFILENAME<-paste(CORCOEFFSOUTPUTFILE,"_",TIMEPOINTANALYSED,".csv",sep="")
-		LHCSUMMARYFILENAMEFULL<-paste(LHCSUMMARYFILENAME,"_",TIMEPOINTANALYSED,".csv",sep="")
+		CORCOEFFSFILENAME<-paste(CORCOEFFSOUTPUTFILE,"_",TIMEPOINTANALYSED,sep="")
+		LHCSUMMARYFILENAMEFULL<-paste(LHCSUMMARYFILENAME,"_",TIMEPOINTANALYSED,sep="")
 
 		lhc_graphMeasuresForParameterChange(FILEPATH,PARAMETERS,MEASURES,MEASURE_SCALE,CORCOEFFSFILENAME,LHCSUMMARYFILENAMEFULL,TIMEPOINTANALYSED,TIMEPOINTSCALE)
 	}
