@@ -1,10 +1,13 @@
 lhc_process_sample_run_subsets <-
-function(FILEPATH,NUMSAMPLES,NUMRUNSPERSAMPLE,OUTPUTCOLSTART,OUTPUTCOLEND,MEASURES,RESULTFILENAME,ALTERNATIVEFILENAME,MEDIANSFILENAME)
+function(FILEPATH,NUMSAMPLES,NUMRUNSPERSAMPLE,MEASURES,RESULTFILEFORMAT,RESULTFILENAME,ALTERNATIVEFILENAME,OUTPUTCOLSTART,OUTPUTCOLEND,
+		MEDIANSFILEFORMAT,MEDIANSFILENAME)
 {
 	if(file.exists(FILEPATH))
 	{
 		print("Generating Simulation Median Responses (lhc_process_sample_run_subsets)")
-
+		
+		MEDIANSFILEFORMAT<-tolower(MEDIANSFILEFORMAT)
+		
 		for(k in 1:NUMSAMPLES)
 		{
 			print(paste("Generating Median Simulation Responses for Parameter Set ",k,sep=""))
@@ -12,11 +15,13 @@ function(FILEPATH,NUMSAMPLES,NUMRUNSPERSAMPLE,OUTPUTCOLSTART,OUTPUTCOLEND,MEASUR
 			
 			# CHECK WHETHER THIS HAS ALREADY BEEN DONE (SAVES TIME IN ERROR CIRCUMSTANCES)
 			MEDIANRESULTSFILE = paste(MEDIANFILEPATH,"/",MEDIANSFILENAME,sep="")
-	
-			if(!file.exists(MEDIANRESULTSFILE))
+			#print(MEDIANRESULTSFILE)
+			
+			
+			if(!file.exists(paste(MEDIANRESULTSFILE,".",MEDIANSFILEFORMAT,sep="")))
 			{
-				getMediansSubset(MEDIANFILEPATH,NUMRUNSPERSAMPLE,OUTPUTCOLSTART,OUTPUTCOLEND,MEASURES,
-					RESULTFILENAME,ALTERNATIVEFILENAME,MEDIANSFILENAME)
+				getMediansSubset(MEDIANFILEPATH,NUMRUNSPERSAMPLE,MEASURES,RESULTFILEFORMAT,RESULTFILENAME,ALTERNATIVEFILENAME,
+						OUTPUTCOLSTART,OUTPUTCOLEND,MEDIANSFILEFORMAT,MEDIANSFILENAME)
 			}
 		}
 		
